<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Tripwires Index

Complete index of category-specific tripwire files.

## Universal Tripwires

Load **first** for any code area: [universal-tripwires.md](universal-tripwires.md)

## Category Tripwires

| Category                                    | Tripwires | Load When Working In                          |
| ------------------------------------------- | --------- | --------------------------------------------- |
| [architecture](architecture/tripwires.md)   | 81        | `src/erk/gateway/`, gateways, subprocess      |
| [capabilities](capabilities/tripwires.md)   | 1         | Claude Code capabilities, tool use            |
| [ci](ci/tripwires.md)                       | 22        | `.github/workflows/`, `.github/actions/`      |
| [claude-code](claude-code/tripwires.md)     | 2         | Claude Code configuration, settings           |
| [cli](cli/tripwires.md)                     | 30        | `src/erk/cli/`                                |
| [desktop-dash](desktop-dash/tripwires.md)   | 16        | `desktop-dash/` code                          |
| [gateway](gateway/tripwires.md)             | 2         | `gateway/` code                               |
| [hooks](hooks/tripwires.md)                 | 2         | `.claude/hooks/`, hook development            |
| [objectives](objectives/tripwires.md)       | 9         | `objectives/` code                            |
| [planning](planning/tripwires.md)           | 25        | `.impl/`, `.worker-impl/`, planning workflows |
| [pr-operations](pr-operations/tripwires.md) | 1         | `pr-operations/` code                         |
| [reference](reference/tripwires.md)         | 3         | `reference/` code                             |
| [review](review/tripwires.md)               | 3         | `review/` code                                |
| [reviews](reviews/tripwires.md)             | 1         | `reviews/` code                               |
| [sessions](sessions/tripwires.md)           | 6         | `~/.claude/projects/`, session analysis       |
| [testing](testing/tripwires.md)             | 17        | `tests/`                                      |
| [textual](textual/tripwires.md)             | 1         | Textual framework code                        |
| [tui](tui/tripwires.md)                     | 5         | `src/erk/tui/`                                |
| [uncategorized](uncategorized/tripwires.md) | 14        | `uncategorized/` code                         |
